@@ -2,22 +2,25 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Kontakti",
-    "Invalid image" : "Nevažeća datoteka",
-    "Loading" : "Loading",
-    "Name" : "Ime",
-    "Title" : "Naslov",
     "Download" : "Preuzmi",
-    "Delete" : "Obriši",
-    "Cancel" : "Otkaži",
     "Groups" : "Grupe",
-    "New contact" : "Novi kontakt",
+    "Group name" : "Naziv grupe",
     "Rename" : "Preimenuj",
     "Enabled" : "Aktivirano",
     "Disabled" : "Onemogućeno",
+    "Delete" : "Obriši",
     "can edit" : "mogu mijenjati",
     "First name" : "Ime",
     "Last name" : "Prezime",
+    "Invalid image" : "Nevažeća datoteka",
+    "Name" : "Ime",
+    "Title" : "Naslov",
+    "Cancel" : "Otkaži",
+    "New contact" : "Novi kontakt",
+    "Close" : "Zatvori",
+    "Import" : "Uvoz",
     "Not grouped" : "Nije grupirano",
+    "Email" : "E-pošta",
     "Nickname" : "Nadimak",
     "Additional names" : "Dodatna imena",
     "Notes" : "Notes",
@@ -32,7 +35,6 @@ OC.L10N.register(
     "Postal code" : "Poštanski broj",
     "Country" : "Država",
     "Birthday" : "Rođendan",
-    "Email" : "E-pošta",
     "Instant messaging" : "Razmjena izravnih poruka",
     "Phone" : "Telefon",
     "Mobile" : "Mobitel",
