@@ -1,23 +1,24 @@
 OC.L10N.register(
     "contacts",
     {
-    "Invalid image" : "ಅಸಾಮರ್ಥ್ಯ ಚಿತ್ರ",
-    "Loading" : "Loading",
-    "Name" : "﻿ಹೆಸರು",
-    "Title" : "ಶೀರ್ಷಿಕೆ",
     "Download" : "ಪ್ರತಿಯನ್ನು ಸ್ಥಳೀಯವಾಗಿ ಉಳಿಸಿಕೊಳ್ಳಿ",
-    "Delete" : "﻿ಅಳಿಸಿ",
-    "Cancel" : "﻿ರದ್ದು",
     "Groups" : "﻿ಗುಂಪುಗಳು",
     "Rename" : "﻿ಮರುಹೆಸರಿಸು",
     "Enabled" : "ಸಕ್ರಿಯಗೊಳಿಸಿದೆ",
     "Disabled" : "ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಲಾಗಿದೆ",
+    "Delete" : "﻿ಅಳಿಸಿ",
     "can edit" : "﻿ಸಂಪಾದಿಸಬಹುದು",
+    "Invalid image" : "ಅಸಾಮರ್ಥ್ಯ ಚಿತ್ರ",
+    "Name" : "﻿ಹೆಸರು",
+    "Title" : "ಶೀರ್ಷಿಕೆ",
+    "Cancel" : "﻿ರದ್ದು",
+    "Close" : "ಮುಚ್ಚು",
+    "Import" : "ಆಮದು",
+    "Email" : "﻿ಇ-ಅಂಚೆ",
     "Notes" : "Notes",
     "Home" : "﻿ಮುಖಪುಟ",
     "Other" : "﻿ಇತರೆ",
     "Address" : "ವಿಳಾಸ",
-    "Email" : "﻿ಇ-ಅಂಚೆ",
     "None" : "﻿ಯಾವುದೂ ಇಲ್ಲ"
 },
 "nplurals=2; plural=(n > 1);");
